/* media-manager.c generated by valac 0.22.0.39-4730, the Vala compiler
 * generated from media-manager.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gudev/gudev.h>
#include <libtracker-sparql/tracker-sparql.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include <libvirt-gconfig/libvirt-gconfig.h>
#include <osinfo/osinfo.h>
#include <libcommon.h>
#include <gtk/gtk.h>
#include <glib/gstdio.h>
#include <glib/gi18n-lib.h>


#define BOXES_TYPE_MEDIA_MANAGER (boxes_media_manager_get_type ())
#define BOXES_MEDIA_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManager))
#define BOXES_MEDIA_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManagerClass))
#define BOXES_IS_MEDIA_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MEDIA_MANAGER))
#define BOXES_IS_MEDIA_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MEDIA_MANAGER))
#define BOXES_MEDIA_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManagerClass))

typedef struct _BoxesMediaManager BoxesMediaManager;
typedef struct _BoxesMediaManagerClass BoxesMediaManagerClass;
typedef struct _BoxesMediaManagerPrivate BoxesMediaManagerPrivate;

#define BOXES_TYPE_OS_DATABASE (boxes_os_database_get_type ())
#define BOXES_OS_DATABASE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_OS_DATABASE, BoxesOSDatabase))
#define BOXES_OS_DATABASE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_OS_DATABASE, BoxesOSDatabaseClass))
#define BOXES_IS_OS_DATABASE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_OS_DATABASE))
#define BOXES_IS_OS_DATABASE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_OS_DATABASE))
#define BOXES_OS_DATABASE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_OS_DATABASE, BoxesOSDatabaseClass))

typedef struct _BoxesOSDatabase BoxesOSDatabase;
typedef struct _BoxesOSDatabaseClass BoxesOSDatabaseClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))

#define BOXES_TYPE_INSTALLER_MEDIA (boxes_installer_media_get_type ())
#define BOXES_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMedia))
#define BOXES_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))
#define BOXES_IS_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_IS_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_INSTALLER_MEDIA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))

typedef struct _BoxesInstallerMedia BoxesInstallerMedia;
typedef struct _BoxesInstallerMediaClass BoxesInstallerMediaClass;

#define BOXES_TYPE_INSTALLED_MEDIA (boxes_installed_media_get_type ())
#define BOXES_INSTALLED_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_INSTALLED_MEDIA, BoxesInstalledMedia))
#define BOXES_INSTALLED_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_INSTALLED_MEDIA, BoxesInstalledMediaClass))
#define BOXES_IS_INSTALLED_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_INSTALLED_MEDIA))
#define BOXES_IS_INSTALLED_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_INSTALLED_MEDIA))
#define BOXES_INSTALLED_MEDIA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_INSTALLED_MEDIA, BoxesInstalledMediaClass))

typedef struct _BoxesInstalledMedia BoxesInstalledMedia;
typedef struct _BoxesInstalledMediaClass BoxesInstalledMediaClass;
typedef struct _BoxesMediaManagerCreateInstallerMediaForPathData BoxesMediaManagerCreateInstallerMediaForPathData;
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _BoxesMediaManagerCreateInstallerMediaFromConfigData BoxesMediaManagerCreateInstallerMediaFromConfigData;
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))
typedef struct _BoxesMediaManagerListInstallerMediasData BoxesMediaManagerListInstallerMediasData;
typedef struct _BoxesInstallerMediaPrivate BoxesInstallerMediaPrivate;

#define BOXES_TYPE_VM_CREATOR (boxes_vm_creator_get_type ())
#define BOXES_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreator))
#define BOXES_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))
#define BOXES_IS_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_VM_CREATOR))
#define BOXES_IS_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_VM_CREATOR))
#define BOXES_VM_CREATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))

typedef struct _BoxesVMCreator BoxesVMCreator;
typedef struct _BoxesVMCreatorClass BoxesVMCreatorClass;

#define BOXES_TYPE_UNATTENDED_INSTALLER (boxes_unattended_installer_get_type ())
#define BOXES_UNATTENDED_INSTALLER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UNATTENDED_INSTALLER, BoxesUnattendedInstaller))
#define BOXES_UNATTENDED_INSTALLER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UNATTENDED_INSTALLER, BoxesUnattendedInstallerClass))
#define BOXES_IS_UNATTENDED_INSTALLER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UNATTENDED_INSTALLER))
#define BOXES_IS_UNATTENDED_INSTALLER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UNATTENDED_INSTALLER))
#define BOXES_UNATTENDED_INSTALLER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UNATTENDED_INSTALLER, BoxesUnattendedInstallerClass))

typedef struct _BoxesUnattendedInstaller BoxesUnattendedInstaller;
typedef struct _BoxesUnattendedInstallerClass BoxesUnattendedInstallerClass;
typedef struct _BoxesMediaManagerCreateInstallerMediaFromIsoInfoData BoxesMediaManagerCreateInstallerMediaFromIsoInfoData;

struct _BoxesMediaManager {
	GObject parent_instance;
	BoxesMediaManagerPrivate * priv;
};

struct _BoxesMediaManagerClass {
	GObjectClass parent_class;
};

struct _BoxesMediaManagerPrivate {
	BoxesOSDatabase* _os_db;
	GUdevClient* _client;
	TrackerSparqlConnection* connection;
};

struct _BoxesMediaManagerCreateInstallerMediaForPathData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesMediaManager* self;
	gchar* path;
	GCancellable* cancellable;
	BoxesInstallerMedia* result;
	BoxesInstallerMedia* media;
	const gchar* _tmp0_;
	gboolean _tmp1_;
	BoxesInstallerMedia* _tmp2_;
	const gchar* _tmp3_;
	GCancellable* _tmp4_;
	BoxesInstallerMedia* _tmp5_;
	BoxesInstalledMedia* _tmp6_;
	const gchar* _tmp7_;
	BoxesInstalledMedia* _tmp8_;
	BoxesInstallerMedia* _tmp9_;
	BoxesInstallerMedia* _tmp10_;
	BoxesInstallerMedia* _tmp11_;
	GError * _inner_error_;
};

typedef enum  {
	BOXES_OS_DATABASE_ERROR_NON_BOOTABLE,
	BOXES_OS_DATABASE_ERROR_UNKNOWN_OS_ID,
	BOXES_OS_DATABASE_ERROR_UNKNOWN_MEDIA_ID
} BoxesOSDatabaseError;
#define BOXES_OS_DATABASE_ERROR boxes_os_database_error_quark ()
struct _BoxesMediaManagerCreateInstallerMediaFromConfigData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesMediaManager* self;
	GVirConfigDomain* config;
	BoxesInstallerMedia* result;
	gchar* path;
	GVirConfigDomain* _tmp0_;
	gchar* _tmp1_;
	const gchar* _tmp2_;
	GVirConfigDomain* _tmp3_;
	gboolean _tmp4_;
	BoxesInstalledMedia* _tmp5_;
	const gchar* _tmp6_;
	BoxesInstalledMedia* _tmp7_;
	GError* _error_;
	GError* _tmp8_;
	const gchar* _tmp9_;
	gchar* label;
	GVirConfigDomain* _tmp10_;
	const gchar* _tmp11_;
	const gchar* _tmp12_;
	gchar* _tmp13_;
	OsinfoOs* os;
	OsinfoMedia* os_media;
	gchar* os_id;
	GVirConfigDomain* _tmp14_;
	gchar* _tmp15_;
	const gchar* _tmp16_;
	OsinfoOs* _tmp17_;
	BoxesOSDatabase* _tmp18_;
	const gchar* _tmp19_;
	OsinfoOs* _tmp20_;
	gchar* media_id;
	GVirConfigDomain* _tmp21_;
	gchar* _tmp22_;
	const gchar* _tmp23_;
	OsinfoMedia* _tmp24_;
	BoxesOSDatabase* _tmp25_;
	OsinfoOs* _tmp26_;
	const gchar* _tmp27_;
	OsinfoMedia* _tmp28_;
	GError* _vala1__error_;
	GError* _tmp29_;
	const gchar* _tmp30_;
	gchar* _tmp31_;
	OsinfoMedia* _tmp32_;
	OsinfoMedia* _tmp33_;
	gchar* _tmp34_;
	gchar* _tmp35_;
	gchar* architecture;
	const gchar* _tmp36_;
	gchar* _tmp37_;
	OsinfoResources* resources;
	BoxesOSDatabase* _tmp38_;
	OsinfoOs* _tmp39_;
	const gchar* _tmp40_;
	OsinfoResources* _tmp41_;
	BoxesInstallerMedia* media;
	const gchar* _tmp42_;
	const gchar* _tmp43_;
	OsinfoOs* _tmp44_;
	OsinfoMedia* _tmp45_;
	OsinfoResources* _tmp46_;
	BoxesInstallerMedia* _tmp47_;
	BoxesInstallerMedia* _tmp48_;
	BoxesInstallerMedia* _tmp49_;
	BoxesInstallerMedia* _tmp50_;
	BoxesInstallerMedia* _tmp51_;
	GError* _vala2__error_;
	GError* _tmp52_;
	const gchar* _tmp53_;
	GError * _inner_error_;
};

struct _BoxesMediaManagerListInstallerMediasData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesMediaManager* self;
	GList* result;
	GList* list;
	GUdevEnumerator* enumerator;
	GUdevClient* _tmp0_;
	GUdevEnumerator* _tmp1_;
	GUdevEnumerator* _tmp2_;
	GUdevEnumerator* _tmp3_;
	GList* _tmp4_;
	GList* device_collection;
	GList* device_it;
	GUdevDevice* _tmp5_;
	GUdevDevice* device;
	gboolean _tmp6_;
	GUdevDevice* _tmp7_;
	const gchar* _tmp8_;
	GUdevDevice* _tmp9_;
	gboolean _tmp10_;
	gboolean _tmp11_;
	gchar* path;
	GUdevDevice* _tmp12_;
	const gchar* _tmp13_;
	gchar* _tmp14_;
	BoxesInstallerMedia* media;
	const gchar* _tmp15_;
	BoxesInstallerMedia* _tmp16_;
	BoxesInstallerMedia* _tmp17_;
	BoxesInstallerMedia* _tmp18_;
	GError* _error_;
	const gchar* _tmp19_;
	GError* _tmp20_;
	const gchar* _tmp21_;
	TrackerSparqlConnection* _tmp22_;
	TrackerSparqlCursor* cursor;
	TrackerSparqlConnection* _tmp23_;
	TrackerSparqlCursor* _tmp24_;
	gboolean _tmp25_;
	TrackerSparqlCursor* _tmp26_;
	gboolean _tmp27_;
	GFile* file;
	TrackerSparqlCursor* _tmp28_;
	const gchar* _tmp29_;
	GFile* _tmp30_;
	gchar* _vala1_path;
	GFile* _tmp31_;
	gchar* _tmp32_;
	const gchar* _tmp33_;
	gchar* title;
	TrackerSparqlCursor* _tmp34_;
	const gchar* _tmp35_;
	gchar* _tmp36_;
	gchar* os_id;
	TrackerSparqlCursor* _tmp37_;
	const gchar* _tmp38_;
	gchar* _tmp39_;
	gchar* media_id;
	TrackerSparqlCursor* _tmp40_;
	const gchar* _tmp41_;
	gchar* _tmp42_;
	BoxesInstallerMedia* _vala1_media;
	const gchar* _tmp43_;
	const gchar* _tmp44_;
	const gchar* _tmp45_;
	const gchar* _tmp46_;
	BoxesInstallerMedia* _tmp47_;
	BoxesInstallerMedia* _tmp48_;
	BoxesInstallerMedia* _tmp49_;
	GError* _vala1__error_;
	const gchar* _tmp50_;
	GError* _tmp51_;
	const gchar* _tmp52_;
	GError* _vala2__error_;
	GError* _tmp53_;
	const gchar* _tmp54_;
	GError * _inner_error_;
};

struct _BoxesInstallerMedia {
	GObject parent_instance;
	BoxesInstallerMediaPrivate * priv;
	OsinfoOs* os;
	OsinfoResources* resources;
	OsinfoMedia* os_media;
	gchar* label;
	gchar* device_file;
	gchar* mount_point;
	gboolean from_image;
};

struct _BoxesInstallerMediaClass {
	GObjectClass parent_class;
	void (*set_direct_boot_params) (BoxesInstallerMedia* self, GVirConfigDomainOs* os);
	void (*prepare) (BoxesInstallerMedia* self, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*prepare_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_);
	void (*prepare_for_installation) (BoxesInstallerMedia* self, const gchar* vm_name, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*prepare_for_installation_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_, GError** error);
	void (*prepare_to_continue_installation) (BoxesInstallerMedia* self, const gchar* vm_name);
	void (*clean_up) (BoxesInstallerMedia* self);
	void (*clean_up_preparation_cache) (BoxesInstallerMedia* self);
	void (*setup_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*setup_post_install_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*populate_setup_vbox) (BoxesInstallerMedia* self, GtkBox* setup_vbox);
	GList* (*get_vm_properties) (BoxesInstallerMedia* self);
	BoxesVMCreator* (*get_vm_creator) (BoxesInstallerMedia* self);
	OsinfoDeviceList* (*get_supported_devices) (BoxesInstallerMedia* self);
	guint64 (*get_installed_size) (BoxesInstallerMedia* self);
	gboolean (*get_need_user_input_for_vm_creation) (BoxesInstallerMedia* self);
	gboolean (*get_ready_to_create) (BoxesInstallerMedia* self);
	gboolean (*get_live) (BoxesInstallerMedia* self);
	gchar* (*get_architecture) (BoxesInstallerMedia* self);
};

struct _BoxesMediaManagerCreateInstallerMediaFromIsoInfoData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesMediaManager* self;
	gchar* path;
	gchar* label;
	gchar* os_id;
	gchar* media_id;
	BoxesInstallerMedia* result;
	const gchar* _tmp0_;
	gboolean _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	GError* _tmp6_;
	GError* _tmp7_;
	gboolean _tmp8_;
	gboolean _tmp9_;
	const gchar* _tmp10_;
	const gchar* _tmp11_;
	gboolean _tmp12_;
	const gchar* _tmp13_;
	gboolean _tmp14_;
	BoxesInstallerMedia* _tmp15_;
	const gchar* _tmp16_;
	BoxesInstallerMedia* _tmp17_;
	OsinfoOs* os;
	BoxesOSDatabase* _tmp18_;
	const gchar* _tmp19_;
	OsinfoOs* _tmp20_;
	OsinfoMedia* os_media;
	BoxesOSDatabase* _tmp21_;
	OsinfoOs* _tmp22_;
	const gchar* _tmp23_;
	OsinfoMedia* _tmp24_;
	OsinfoResources* resources;
	BoxesOSDatabase* _tmp25_;
	OsinfoOs* _tmp26_;
	OsinfoMedia* _tmp27_;
	gchar* _tmp28_;
	gchar* _tmp29_;
	gchar* _tmp30_;
	OsinfoResources* _tmp31_;
	OsinfoResources* _tmp32_;
	BoxesInstallerMedia* media;
	const gchar* _tmp33_;
	const gchar* _tmp34_;
	OsinfoOs* _tmp35_;
	OsinfoMedia* _tmp36_;
	OsinfoResources* _tmp37_;
	BoxesInstallerMedia* _tmp38_;
	BoxesInstallerMedia* _tmp39_;
	BoxesInstallerMedia* _tmp40_;
	BoxesInstallerMedia* _tmp41_;
	GError * _inner_error_;
};

typedef void (*BoxesMediaManagerInstallerRecognized) (OsinfoMedia* os_media, OsinfoOs* os, void* user_data);

static gpointer boxes_media_manager_parent_class = NULL;
static BoxesMediaManager* boxes_media_manager_media_manager;
static BoxesMediaManager* boxes_media_manager_media_manager = NULL;

GType boxes_media_manager_get_type (void) G_GNUC_CONST;
GType boxes_os_database_get_type (void) G_GNUC_CONST;
#define BOXES_MEDIA_MANAGER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManagerPrivate))
enum  {
	BOXES_MEDIA_MANAGER_DUMMY_PROPERTY,
	BOXES_MEDIA_MANAGER_OS_DB,
	BOXES_MEDIA_MANAGER_CLIENT
};
#define BOXES_MEDIA_MANAGER_SPARQL_QUERY "SELECT nie:url(?iso) nie:title(?iso) osinfo:id(?iso) osinfo:mediaId(?i" \
"so)" " { ?iso nfo:isBootable true }"
BoxesMediaManager* boxes_media_manager_get_instance (void);
static BoxesMediaManager* boxes_media_manager_new (void);
static BoxesMediaManager* boxes_media_manager_construct (GType object_type);
static void boxes_media_manager_create_installer_media_for_path_data_free (gpointer _data);
GType boxes_installer_media_get_type (void) G_GNUC_CONST;
void boxes_media_manager_create_installer_media_for_path (BoxesMediaManager* self, const gchar* path, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
BoxesInstallerMedia* boxes_media_manager_create_installer_media_for_path_finish (BoxesMediaManager* self, GAsyncResult* _res_, GError** error);
static gboolean boxes_media_manager_create_installer_media_for_path_co (BoxesMediaManagerCreateInstallerMediaForPathData* _data_);
gboolean boxes_is_mime_type (const gchar* filename, const gchar* mime_type);
void boxes_installer_media_new_for_path (const gchar* path, BoxesMediaManager* media_manager, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
BoxesInstallerMedia* boxes_installer_media_new_for_path_finish (GAsyncResult* _res_, GError** error);
void boxes_installer_media_construct_for_path (GType object_type, const gchar* path, BoxesMediaManager* media_manager, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
BoxesInstallerMedia* boxes_installer_media_construct_for_path_finish (GAsyncResult* _res_, GError** error);
static void boxes_media_manager_create_installer_media_for_path_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
GType boxes_installed_media_get_type (void) G_GNUC_CONST;
void boxes_installed_media_new (const gchar* path, BoxesMediaManager* media_manager, GAsyncReadyCallback _callback_, gpointer _user_data_);
BoxesInstalledMedia* boxes_installed_media_new_finish (GAsyncResult* _res_, GError** error);
void boxes_installed_media_construct (GType object_type, const gchar* path, BoxesMediaManager* media_manager, GAsyncReadyCallback _callback_, gpointer _user_data_);
BoxesInstalledMedia* boxes_installed_media_construct_finish (GAsyncResult* _res_, GError** error);
BoxesInstallerMedia* boxes_media_manager_create_installer_media_from_media (BoxesMediaManager* self, BoxesInstallerMedia* media, GError** error);
static void boxes_media_manager_create_installer_media_from_config_data_free (gpointer _data);
void boxes_media_manager_create_installer_media_from_config (BoxesMediaManager* self, GVirConfigDomain* config, GAsyncReadyCallback _callback_, gpointer _user_data_);
BoxesInstallerMedia* boxes_media_manager_create_installer_media_from_config_finish (BoxesMediaManager* self, GAsyncResult* _res_);
static gboolean boxes_media_manager_create_installer_media_from_config_co (BoxesMediaManagerCreateInstallerMediaFromConfigData* _data_);
gchar* boxes_vm_configurator_get_source_media_path (GVirConfigDomain* domain);
gboolean boxes_vm_configurator_is_import_config (GVirConfigDomain* domain);
static void boxes_media_manager_create_installer_media_from_config_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
gchar* boxes_vm_configurator_get_os_id (GVirConfigDomain* domain);
BoxesOSDatabase* boxes_media_manager_get_os_db (BoxesMediaManager* self);
void boxes_os_database_get_os_by_id (BoxesOSDatabase* self, const gchar* id, GAsyncReadyCallback _callback_, gpointer _user_data_);
GQuark boxes_os_database_error_quark (void);
OsinfoOs* boxes_os_database_get_os_by_id_finish (BoxesOSDatabase* self, GAsyncResult* _res_, GError** error);
gchar* boxes_vm_configurator_get_os_media_id (GVirConfigDomain* domain);
OsinfoMedia* boxes_os_database_get_media_by_id (BoxesOSDatabase* self, OsinfoOs* os, const gchar* id, GError** error);
OsinfoResources* boxes_os_database_get_resources_for_os (BoxesOSDatabase* self, OsinfoOs* os, const gchar* architecture);
BoxesInstallerMedia* boxes_installer_media_new_from_iso_info (const gchar* path, const gchar* label, OsinfoOs* os, OsinfoMedia* media, OsinfoResources* resources);
BoxesInstallerMedia* boxes_installer_media_construct_from_iso_info (GType object_type, const gchar* path, const gchar* label, OsinfoOs* os, OsinfoMedia* media, OsinfoResources* resources);
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
static void boxes_media_manager_list_installer_medias_data_free (gpointer _data);
void boxes_media_manager_list_installer_medias (BoxesMediaManager* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
GList* boxes_media_manager_list_installer_medias_finish (BoxesMediaManager* self, GAsyncResult* _res_);
static gboolean boxes_media_manager_list_installer_medias_co (BoxesMediaManagerListInstallerMediasData* _data_);
GUdevClient* boxes_media_manager_get_client (BoxesMediaManager* self);
static void boxes_media_manager_list_installer_medias_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_media_manager_create_installer_media_from_iso_info (BoxesMediaManager* self, const gchar* path, const gchar* label, const gchar* os_id, const gchar* media_id, GAsyncReadyCallback _callback_, gpointer _user_data_);
static BoxesInstallerMedia* boxes_media_manager_create_installer_media_from_iso_info_finish (BoxesMediaManager* self, GAsyncResult* _res_, GError** error);
static gint boxes_media_manager_compare_media (BoxesInstallerMedia* media_a, BoxesInstallerMedia* media_b);
static gint _boxes_media_manager_compare_media_gcompare_func (gconstpointer a, gconstpointer b);
gpointer boxes_vm_creator_ref (gpointer instance);
void boxes_vm_creator_unref (gpointer instance);
GParamSpec* boxes_param_spec_vm_creator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void boxes_value_set_vm_creator (GValue* value, gpointer v_object);
void boxes_value_take_vm_creator (GValue* value, gpointer v_object);
gpointer boxes_value_get_vm_creator (const GValue* value);
GType boxes_vm_creator_get_type (void) G_GNUC_CONST;
GType boxes_unattended_installer_get_type (void) G_GNUC_CONST;
BoxesUnattendedInstaller* boxes_unattended_installer_new_from_media (BoxesInstallerMedia* media, OsinfoInstallScriptList* scripts, GError** error);
BoxesUnattendedInstaller* boxes_unattended_installer_construct_from_media (GType object_type, BoxesInstallerMedia* media, OsinfoInstallScriptList* scripts, GError** error);
static void boxes_media_manager_set_client (BoxesMediaManager* self, GUdevClient* value);
BoxesOSDatabase* boxes_os_database_new (void);
BoxesOSDatabase* boxes_os_database_construct (GType object_type);
static void boxes_media_manager_set_os_db (BoxesMediaManager* self, BoxesOSDatabase* value);
void boxes_os_database_load (BoxesOSDatabase* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_os_database_load_finish (BoxesOSDatabase* self, GAsyncResult* _res_);
static void boxes_media_manager_create_installer_media_from_iso_info_data_free (gpointer _data);
static gboolean boxes_media_manager_create_installer_media_from_iso_info_co (BoxesMediaManagerCreateInstallerMediaFromIsoInfoData* _data_);
static void boxes_media_manager_create_installer_media_from_iso_info_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_media_manager_finalize (GObject* obj);
static void _vala_boxes_media_manager_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_media_manager_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);


static gpointer _g_object_ref0 (gpointer self) {
#line 23 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	return self ? g_object_ref (self) : NULL;
#line 485 "media-manager.c"
}


BoxesMediaManager* boxes_media_manager_get_instance (void) {
	BoxesMediaManager* result = NULL;
	BoxesMediaManager* _tmp0_ = NULL;
	BoxesMediaManager* _tmp2_ = NULL;
	BoxesMediaManager* _tmp3_ = NULL;
#line 20 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp0_ = boxes_media_manager_media_manager;
#line 20 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (_tmp0_ == NULL) {
#line 498 "media-manager.c"
		BoxesMediaManager* _tmp1_ = NULL;
#line 21 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_tmp1_ = boxes_media_manager_new ();
#line 21 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (boxes_media_manager_media_manager);
#line 21 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		boxes_media_manager_media_manager = _tmp1_;
#line 506 "media-manager.c"
	}
#line 23 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp2_ = boxes_media_manager_media_manager;
#line 23 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 23 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	result = _tmp3_;
#line 23 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	return result;
#line 516 "media-manager.c"
}


static void boxes_media_manager_create_installer_media_for_path_data_free (gpointer _data) {
	BoxesMediaManagerCreateInstallerMediaForPathData* _data_;
	_data_ = _data;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->path);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->cancellable);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->result);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->self);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_slice_free (BoxesMediaManagerCreateInstallerMediaForPathData, _data_);
#line 533 "media-manager.c"
}


void boxes_media_manager_create_installer_media_for_path (BoxesMediaManager* self, const gchar* path, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesMediaManagerCreateInstallerMediaForPathData* _data_;
	BoxesMediaManager* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	GCancellable* _tmp3_ = NULL;
	GCancellable* _tmp4_ = NULL;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_ = g_slice_new0 (BoxesMediaManagerCreateInstallerMediaForPathData);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_media_manager_create_installer_media_for_path);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_media_manager_create_installer_media_for_path_data_free);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->self = _tmp0_;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp1_ = path;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->path);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->path = _tmp2_;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp3_ = cancellable;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->cancellable);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->cancellable = _tmp4_;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	boxes_media_manager_create_installer_media_for_path_co (_data_);
#line 572 "media-manager.c"
}


BoxesInstallerMedia* boxes_media_manager_create_installer_media_for_path_finish (BoxesMediaManager* self, GAsyncResult* _res_, GError** error) {
	BoxesInstallerMedia* result;
	BoxesMediaManagerCreateInstallerMediaForPathData* _data_;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		return NULL;
#line 583 "media-manager.c"
	}
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	result = _data_->result;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->result = NULL;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	return result;
#line 593 "media-manager.c"
}


static void boxes_media_manager_create_installer_media_for_path_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesMediaManagerCreateInstallerMediaForPathData* _data_;
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_ = _user_data_;
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_source_object_ = source_object;
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_res_ = _res_;
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	boxes_media_manager_create_installer_media_for_path_co (_data_);
#line 607 "media-manager.c"
}


static gboolean boxes_media_manager_create_installer_media_for_path_co (BoxesMediaManagerCreateInstallerMediaForPathData* _data_) {
#line 26 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	switch (_data_->_state_) {
#line 26 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		case 0:
#line 616 "media-manager.c"
		goto _state_0;
#line 26 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		case 1:
#line 620 "media-manager.c"
		goto _state_1;
#line 26 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		case 2:
#line 624 "media-manager.c"
		goto _state_2;
		default:
#line 26 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_assert_not_reached ();
#line 629 "media-manager.c"
	}
	_state_0:
#line 30 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp0_ = NULL;
#line 30 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp0_ = _data_->path;
#line 30 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp1_ = FALSE;
#line 30 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp1_ = boxes_is_mime_type (_data_->_tmp0_, "application/x-cd-image");
#line 30 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (_data_->_tmp1_) {
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp3_ = NULL;
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp3_ = _data_->path;
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp4_ = NULL;
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp4_ = _data_->cancellable;
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_state_ = 1;
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		boxes_installer_media_new_for_path (_data_->_tmp3_, _data_->self, _data_->_tmp4_, boxes_media_manager_create_installer_media_for_path_ready, _data_);
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		return FALSE;
#line 656 "media-manager.c"
		_state_1:
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp5_ = NULL;
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp5_ = boxes_installer_media_new_for_path_finish (_data_->_res_, &_data_->_inner_error_);
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp2_ = _data_->_tmp5_;
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		if (_data_->_inner_error_ != NULL) {
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_error_free (_data_->_inner_error_);
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_g_object_unref0 (_data_->media);
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			if (_data_->_state_ == 0) {
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 676 "media-manager.c"
			} else {
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 680 "media-manager.c"
			}
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_object_unref (_data_->_async_result);
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			return FALSE;
#line 686 "media-manager.c"
		}
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->media);
#line 31 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->media = _data_->_tmp2_;
#line 692 "media-manager.c"
	} else {
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp7_ = NULL;
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp7_ = _data_->path;
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_state_ = 2;
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		boxes_installed_media_new (_data_->_tmp7_, _data_->self, boxes_media_manager_create_installer_media_for_path_ready, _data_);
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		return FALSE;
#line 704 "media-manager.c"
		_state_2:
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp8_ = NULL;
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp8_ = boxes_installed_media_new_finish (_data_->_res_, &_data_->_inner_error_);
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp6_ = _data_->_tmp8_;
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		if (_data_->_inner_error_ != NULL) {
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_error_free (_data_->_inner_error_);
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_g_object_unref0 (_data_->media);
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			if (_data_->_state_ == 0) {
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 724 "media-manager.c"
			} else {
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 728 "media-manager.c"
			}
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_object_unref (_data_->_async_result);
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			return FALSE;
#line 734 "media-manager.c"
		}
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->media);
#line 33 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->media = (BoxesInstallerMedia*) _data_->_tmp6_;
#line 740 "media-manager.c"
	}
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp10_ = NULL;
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp10_ = _data_->media;
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp11_ = NULL;
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp11_ = boxes_media_manager_create_installer_media_from_media (_data_->self, _data_->_tmp10_, &_data_->_inner_error_);
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp9_ = _data_->_tmp11_;
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (_data_->_inner_error_ != NULL) {
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_error_free (_data_->_inner_error_);
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->media);
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		if (_data_->_state_ == 0) {
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 764 "media-manager.c"
		} else {
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 768 "media-manager.c"
		}
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_object_unref (_data_->_async_result);
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		return FALSE;
#line 774 "media-manager.c"
	}
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->result = _data_->_tmp9_;
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->media);
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (_data_->_state_ == 0) {
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 784 "media-manager.c"
	} else {
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 788 "media-manager.c"
	}
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_object_unref (_data_->_async_result);
#line 35 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	return FALSE;
#line 26 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->media);
#line 26 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (_data_->_state_ == 0) {
#line 26 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 800 "media-manager.c"
	} else {
#line 26 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 804 "media-manager.c"
	}
#line 26 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_object_unref (_data_->_async_result);
#line 26 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	return FALSE;
#line 810 "media-manager.c"
}


static void boxes_media_manager_create_installer_media_from_config_data_free (gpointer _data) {
	BoxesMediaManagerCreateInstallerMediaFromConfigData* _data_;
	_data_ = _data;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->config);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->result);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->self);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_slice_free (BoxesMediaManagerCreateInstallerMediaFromConfigData, _data_);
#line 825 "media-manager.c"
}


void boxes_media_manager_create_installer_media_from_config (BoxesMediaManager* self, GVirConfigDomain* config, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesMediaManagerCreateInstallerMediaFromConfigData* _data_;
	BoxesMediaManager* _tmp0_ = NULL;
	GVirConfigDomain* _tmp1_ = NULL;
	GVirConfigDomain* _tmp2_ = NULL;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_ = g_slice_new0 (BoxesMediaManagerCreateInstallerMediaFromConfigData);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_media_manager_create_installer_media_from_config);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_media_manager_create_installer_media_from_config_data_free);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->self = _tmp0_;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp1_ = config;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->config);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->config = _tmp2_;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	boxes_media_manager_create_installer_media_from_config_co (_data_);
#line 854 "media-manager.c"
}


BoxesInstallerMedia* boxes_media_manager_create_installer_media_from_config_finish (BoxesMediaManager* self, GAsyncResult* _res_) {
	BoxesInstallerMedia* result;
	BoxesMediaManagerCreateInstallerMediaFromConfigData* _data_;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	result = _data_->result;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->result = NULL;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	return result;
#line 869 "media-manager.c"
}


static void boxes_media_manager_create_installer_media_from_config_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesMediaManagerCreateInstallerMediaFromConfigData* _data_;
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_ = _user_data_;
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_source_object_ = source_object;
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_res_ = _res_;
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	boxes_media_manager_create_installer_media_from_config_co (_data_);
#line 883 "media-manager.c"
}


static gboolean boxes_media_manager_create_installer_media_from_config_co (BoxesMediaManagerCreateInstallerMediaFromConfigData* _data_) {
#line 38 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	switch (_data_->_state_) {
#line 38 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		case 0:
#line 892 "media-manager.c"
		goto _state_0;
#line 38 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		case 1:
#line 896 "media-manager.c"
		goto _state_1;
#line 38 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		case 2:
#line 900 "media-manager.c"
		goto _state_2;
		default:
#line 38 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_assert_not_reached ();
#line 905 "media-manager.c"
	}
	_state_0:
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp0_ = NULL;
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp0_ = _data_->config;
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp1_ = NULL;
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp1_ = boxes_vm_configurator_get_source_media_path (_data_->_tmp0_);
#line 39 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->path = _data_->_tmp1_;
#line 40 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp2_ = NULL;
#line 40 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp2_ = _data_->path;
#line 40 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (_data_->_tmp2_ == NULL) {
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->result = NULL;
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_free0 (_data_->path);
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		if (_data_->_state_ == 0) {
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 932 "media-manager.c"
		} else {
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 936 "media-manager.c"
		}
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_object_unref (_data_->_async_result);
#line 41 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		return FALSE;
#line 942 "media-manager.c"
	}
#line 43 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp3_ = NULL;
#line 43 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp3_ = _data_->config;
#line 43 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp4_ = FALSE;
#line 43 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp4_ = boxes_vm_configurator_is_import_config (_data_->_tmp3_);
#line 43 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (_data_->_tmp4_) {
#line 954 "media-manager.c"
		{
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp6_ = NULL;
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp6_ = _data_->path;
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_state_ = 1;
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			boxes_installed_media_new (_data_->_tmp6_, _data_->self, boxes_media_manager_create_installer_media_from_config_ready, _data_);
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			return FALSE;
#line 966 "media-manager.c"
			_state_1:
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp7_ = NULL;
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp7_ = boxes_installed_media_new_finish (_data_->_res_, &_data_->_inner_error_);
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp5_ = _data_->_tmp7_;
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			if (_data_->_inner_error_ != NULL) {
#line 976 "media-manager.c"
				goto __catch56_g_error;
			}
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->result = (BoxesInstallerMedia*) _data_->_tmp5_;
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_g_free0 (_data_->path);
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			if (_data_->_state_ == 0) {
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 987 "media-manager.c"
			} else {
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 991 "media-manager.c"
			}
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_object_unref (_data_->_async_result);
#line 45 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			return FALSE;
#line 997 "media-manager.c"
		}
		goto __finally56;
		__catch56_g_error:
		{
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_error_ = _data_->_inner_error_;
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_inner_error_ = NULL;
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp8_ = NULL;
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp8_ = _data_->_error_;
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp9_ = NULL;
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp9_ = _data_->_tmp8_->message;
#line 47 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_debug ("media-manager.vala:47: %s", _data_->_tmp9_);
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->result = NULL;
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_g_error_free0 (_data_->_error_);
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_g_free0 (_data_->path);
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			if (_data_->_state_ == 0) {
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1026 "media-manager.c"
			} else {
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 1030 "media-manager.c"
			}
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_object_unref (_data_->_async_result);
#line 49 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			return FALSE;
#line 1036 "media-manager.c"
		}
		__finally56:
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_free0 (_data_->path);
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_clear_error (&_data_->_inner_error_);
#line 44 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		return FALSE;
#line 1047 "media-manager.c"
	}
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp10_ = NULL;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp10_ = _data_->config;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp11_ = NULL;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp11_ = gvir_config_domain_get_title (_data_->_tmp10_);
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp12_ = NULL;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp12_ = _data_->_tmp11_;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp13_ = NULL;
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp13_ = g_strdup (_data_->_tmp12_);
#line 52 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->label = _data_->_tmp13_;
#line 54 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->os = NULL;
#line 55 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->os_media = NULL;
#line 1071 "media-manager.c"
	{
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp14_ = NULL;
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp14_ = _data_->config;
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp15_ = NULL;
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp15_ = boxes_vm_configurator_get_os_id (_data_->_tmp14_);
#line 58 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->os_id = _data_->_tmp15_;
#line 59 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp16_ = NULL;
#line 59 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp16_ = _data_->os_id;
#line 59 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		if (_data_->_tmp16_ != NULL) {
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp18_ = NULL;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp18_ = _data_->self->priv->_os_db;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp19_ = NULL;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp19_ = _data_->os_id;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_state_ = 2;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			boxes_os_database_get_os_by_id (_data_->_tmp18_, _data_->_tmp19_, boxes_media_manager_create_installer_media_from_config_ready, _data_);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			return FALSE;
#line 1103 "media-manager.c"
			_state_2:
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp20_ = NULL;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp20_ = boxes_os_database_get_os_by_id_finish (_data_->_tmp18_, _data_->_res_, &_data_->_inner_error_);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp17_ = _data_->_tmp20_;
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			if (_data_->_inner_error_ != NULL) {
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_g_free0 (_data_->os_id);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				if (_data_->_inner_error_->domain == BOXES_OS_DATABASE_ERROR) {
#line 1117 "media-manager.c"
					goto __catch57_boxes_os_database_error;
				}
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_g_free0 (_data_->os_id);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_g_object_unref0 (_data_->os_media);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_g_object_unref0 (_data_->os);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_g_free0 (_data_->label);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_g_free0 (_data_->path);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				g_clear_error (&_data_->_inner_error_);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				return FALSE;
#line 1136 "media-manager.c"
			}
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_g_object_unref0 (_data_->os);
#line 60 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->os = _data_->_tmp17_;
#line 62 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp21_ = NULL;
#line 62 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp21_ = _data_->config;
#line 62 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp22_ = NULL;
#line 62 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp22_ = boxes_vm_configurator_get_os_media_id (_data_->_tmp21_);
#line 62 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->media_id = _data_->_tmp22_;
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp23_ = NULL;
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp23_ = _data_->media_id;
#line 63 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			if (_data_->_tmp23_ != NULL) {
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp25_ = NULL;
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp25_ = _data_->self->priv->_os_db;
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp26_ = NULL;
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp26_ = _data_->os;
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp27_ = NULL;
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp27_ = _data_->media_id;
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp28_ = NULL;
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp28_ = boxes_os_database_get_media_by_id (_data_->_tmp25_, _data_->_tmp26_, _data_->_tmp27_, &_data_->_inner_error_);
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp24_ = _data_->_tmp28_;
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				if (_data_->_inner_error_ != NULL) {
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_g_free0 (_data_->media_id);
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_g_free0 (_data_->os_id);
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					if (_data_->_inner_error_->domain == BOXES_OS_DATABASE_ERROR) {
#line 1184 "media-manager.c"
						goto __catch57_boxes_os_database_error;
					}
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_g_free0 (_data_->media_id);
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_g_free0 (_data_->os_id);
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_g_object_unref0 (_data_->os_media);
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_g_object_unref0 (_data_->os);
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_g_free0 (_data_->label);
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_g_free0 (_data_->path);
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					g_clear_error (&_data_->_inner_error_);
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					return FALSE;
#line 1205 "media-manager.c"
				}
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_g_object_unref0 (_data_->os_media);
#line 64 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->os_media = _data_->_tmp24_;
#line 1211 "media-manager.c"
			}
#line 59 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_g_free0 (_data_->media_id);
#line 1215 "media-manager.c"
		}
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_free0 (_data_->os_id);
#line 1219 "media-manager.c"
	}
	goto __finally57;
	__catch57_boxes_os_database_error:
	{
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_vala1__error_ = _data_->_inner_error_;
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_inner_error_ = NULL;
#line 67 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp29_ = NULL;
#line 67 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp29_ = _data_->_vala1__error_;
#line 67 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp30_ = NULL;
#line 67 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp30_ = _data_->_tmp29_->message;
#line 67 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_warning ("media-manager.vala:67: %s", _data_->_tmp30_);
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_error_free0 (_data_->_vala1__error_);
#line 1240 "media-manager.c"
	}
	__finally57:
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (_data_->_inner_error_ != NULL) {
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->os_media);
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->os);
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_free0 (_data_->label);
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_free0 (_data_->path);
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_clear_error (&_data_->_inner_error_);
#line 57 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		return FALSE;
#line 1259 "media-manager.c"
	}
#line 70 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp32_ = NULL;
#line 70 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp32_ = _data_->os_media;
#line 70 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (_data_->_tmp32_ != NULL) {
#line 70 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp33_ = NULL;
#line 70 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp33_ = _data_->os_media;
#line 70 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp34_ = NULL;
#line 70 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_object_get (_data_->_tmp33_, "architecture", &_data_->_tmp34_, NULL);
#line 70 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp35_ = NULL;
#line 70 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp35_ = _data_->_tmp34_;
#line 70 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_free0 (_data_->_tmp31_);
#line 70 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp31_ = _data_->_tmp35_;
#line 1283 "media-manager.c"
	} else {
#line 70 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_free0 (_data_->_tmp31_);
#line 70 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp31_ = NULL;
#line 1289 "media-manager.c"
	}
#line 70 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp36_ = NULL;
#line 70 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp36_ = _data_->_tmp31_;
#line 70 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp37_ = NULL;
#line 70 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp37_ = g_strdup (_data_->_tmp36_);
#line 70 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->architecture = _data_->_tmp37_;
#line 71 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp38_ = NULL;
#line 71 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp38_ = _data_->self->priv->_os_db;
#line 71 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp39_ = NULL;
#line 71 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp39_ = _data_->os;
#line 71 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp40_ = NULL;
#line 71 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp40_ = _data_->architecture;
#line 71 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp41_ = NULL;
#line 71 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp41_ = boxes_os_database_get_resources_for_os (_data_->_tmp38_, _data_->_tmp39_, _data_->_tmp40_);
#line 71 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->resources = _data_->_tmp41_;
#line 73 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp42_ = NULL;
#line 73 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp42_ = _data_->path;
#line 73 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp43_ = NULL;
#line 73 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp43_ = _data_->label;
#line 73 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp44_ = NULL;
#line 73 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp44_ = _data_->os;
#line 73 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp45_ = NULL;
#line 73 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp45_ = _data_->os_media;
#line 73 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp46_ = NULL;
#line 73 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp46_ = _data_->resources;
#line 73 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp47_ = NULL;
#line 73 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp47_ = boxes_installer_media_new_from_iso_info (_data_->_tmp42_, _data_->_tmp43_, _data_->_tmp44_, _data_->_tmp45_, _data_->_tmp46_);
#line 73 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->media = _data_->_tmp47_;
#line 74 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp48_ = NULL;
#line 74 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp48_ = _data_->media;
#line 74 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_return_val_if_fail (_data_->_tmp48_ != NULL, NULL);
#line 1351 "media-manager.c"
	{
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp50_ = NULL;
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp50_ = _data_->media;
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp51_ = NULL;
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp51_ = boxes_media_manager_create_installer_media_from_media (_data_->self, _data_->_tmp50_, &_data_->_inner_error_);
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp49_ = _data_->_tmp51_;
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		if (_data_->_inner_error_ != NULL) {
#line 1365 "media-manager.c"
			goto __catch58_g_error;
		}
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->media);
#line 77 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->media = _data_->_tmp49_;
#line 1372 "media-manager.c"
	}
	goto __finally58;
	__catch58_g_error:
	{
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_vala2__error_ = _data_->_inner_error_;
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_inner_error_ = NULL;
#line 79 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp52_ = NULL;
#line 79 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp52_ = _data_->_vala2__error_;
#line 79 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp53_ = NULL;
#line 79 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp53_ = _data_->_tmp52_->message;
#line 79 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_debug ("media-manager.vala:79: %s", _data_->_tmp53_);
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_error_free0 (_data_->_vala2__error_);
#line 1393 "media-manager.c"
	}
	__finally58:
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (_data_->_inner_error_ != NULL) {
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->media);
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->resources);
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_free0 (_data_->architecture);
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_free0 (_data_->_tmp31_);
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->os_media);
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->os);
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_free0 (_data_->label);
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_free0 (_data_->path);
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_clear_error (&_data_->_inner_error_);
#line 76 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		return FALSE;
#line 1420 "media-manager.c"
	}
#line 82 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->result = _data_->media;
#line 82 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->resources);
#line 82 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->architecture);
#line 82 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->_tmp31_);
#line 82 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->os_media);
#line 82 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->os);
#line 82 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->label);
#line 82 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->path);
#line 82 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (_data_->_state_ == 0) {
#line 82 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1442 "media-manager.c"
	} else {
#line 82 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1446 "media-manager.c"
	}
#line 82 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_object_unref (_data_->_async_result);
#line 82 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	return FALSE;
#line 38 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->media);
#line 38 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->resources);
#line 38 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->architecture);
#line 38 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->_tmp31_);
#line 38 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->os_media);
#line 38 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->os);
#line 38 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->label);
#line 38 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->path);
#line 38 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (_data_->_state_ == 0) {
#line 38 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1472 "media-manager.c"
	} else {
#line 38 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1476 "media-manager.c"
	}
#line 38 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_object_unref (_data_->_async_result);
#line 38 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	return FALSE;
#line 1482 "media-manager.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 1489 "media-manager.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_list_free (self);
#line 1498 "media-manager.c"
}


static void boxes_media_manager_list_installer_medias_data_free (gpointer _data) {
	BoxesMediaManagerListInstallerMediasData* _data_;
	_data_ = _data;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	__g_list_free__g_object_unref0_0 (_data_->result);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->self);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_slice_free (BoxesMediaManagerListInstallerMediasData, _data_);
#line 1511 "media-manager.c"
}


void boxes_media_manager_list_installer_medias (BoxesMediaManager* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesMediaManagerListInstallerMediasData* _data_;
	BoxesMediaManager* _tmp0_ = NULL;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_ = g_slice_new0 (BoxesMediaManagerListInstallerMediasData);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_media_manager_list_installer_medias);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_media_manager_list_installer_medias_data_free);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->self = _tmp0_;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	boxes_media_manager_list_installer_medias_co (_data_);
#line 1530 "media-manager.c"
}


GList* boxes_media_manager_list_installer_medias_finish (BoxesMediaManager* self, GAsyncResult* _res_) {
	GList* result;
	BoxesMediaManagerListInstallerMediasData* _data_;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	result = _data_->result;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->result = NULL;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	return result;
#line 1545 "media-manager.c"
}


static void boxes_media_manager_list_installer_medias_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesMediaManagerListInstallerMediasData* _data_;
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_ = _user_data_;
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_source_object_ = source_object;
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_res_ = _res_;
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	boxes_media_manager_list_installer_medias_co (_data_);
#line 1559 "media-manager.c"
}


static gint _boxes_media_manager_compare_media_gcompare_func (gconstpointer a, gconstpointer b) {
	gint result;
	result = boxes_media_manager_compare_media (a, b);
#line 126 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	return result;
#line 1568 "media-manager.c"
}


static gboolean boxes_media_manager_list_installer_medias_co (BoxesMediaManagerListInstallerMediasData* _data_) {
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	switch (_data_->_state_) {
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		case 0:
#line 1577 "media-manager.c"
		goto _state_0;
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		case 1:
#line 1581 "media-manager.c"
		goto _state_1;
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		case 2:
#line 1585 "media-manager.c"
		goto _state_2;
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		case 3:
#line 1589 "media-manager.c"
		goto _state_3;
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		case 4:
#line 1593 "media-manager.c"
		goto _state_4;
		default:
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_assert_not_reached ();
#line 1598 "media-manager.c"
	}
	_state_0:
#line 86 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->list = NULL;
#line 89 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp0_ = NULL;
#line 89 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp0_ = _data_->self->priv->_client;
#line 89 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp1_ = NULL;
#line 89 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp1_ = g_udev_enumerator_new (_data_->_tmp0_);
#line 89 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->enumerator = _data_->_tmp1_;
#line 91 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp2_ = NULL;
#line 91 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp2_ = _data_->enumerator;
#line 91 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_udev_enumerator_add_match_property (_data_->_tmp2_, "DEVTYPE", "disk");
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp3_ = NULL;
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp3_ = _data_->enumerator;
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp4_ = NULL;
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp4_ = g_udev_enumerator_execute (_data_->_tmp3_);
#line 1627 "media-manager.c"
	{
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->device_collection = _data_->_tmp4_;
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		for (_data_->device_it = _data_->device_collection; _data_->device_it != NULL; _data_->device_it = _data_->device_it->next) {
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp5_ = NULL;
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp5_ = _g_object_ref0 ((GUdevDevice*) _data_->device_it->data);
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->device = _data_->_tmp5_;
#line 1639 "media-manager.c"
			{
#line 94 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp7_ = NULL;
#line 94 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp7_ = _data_->device;
#line 94 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp8_ = NULL;
#line 94 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp8_ = g_udev_device_get_property (_data_->_tmp7_, "ID_FS_BOOT_SYSTEM_ID");
#line 94 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				if (_data_->_tmp8_ == NULL) {
#line 95 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp9_ = NULL;
#line 95 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp9_ = _data_->device;
#line 95 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp10_ = FALSE;
#line 95 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp10_ = g_udev_device_get_property_as_boolean (_data_->_tmp9_, "OSINFO_BOOTABLE");
#line 95 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp6_ = !_data_->_tmp10_;
#line 1661 "media-manager.c"
				} else {
#line 94 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp6_ = FALSE;
#line 1665 "media-manager.c"
				}
#line 94 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp11_ = FALSE;
#line 94 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp11_ = _data_->_tmp6_;
#line 94 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				if (_data_->_tmp11_) {
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_g_object_unref0 (_data_->device);
#line 96 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					continue;
#line 1677 "media-manager.c"
				}
#line 98 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp12_ = NULL;
#line 98 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp12_ = _data_->device;
#line 98 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp13_ = NULL;
#line 98 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp13_ = g_udev_device_get_device_file (_data_->_tmp12_);
#line 98 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp14_ = NULL;
#line 98 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp14_ = g_strdup (_data_->_tmp13_);
#line 98 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->path = _data_->_tmp14_;
#line 1693 "media-manager.c"
				{
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp15_ = NULL;
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp15_ = _data_->path;
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_state_ = 1;
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					boxes_media_manager_create_installer_media_for_path (_data_->self, _data_->_tmp15_, NULL, boxes_media_manager_list_installer_medias_ready, _data_);
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					return FALSE;
#line 1705 "media-manager.c"
					_state_1:
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp16_ = NULL;
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp16_ = boxes_media_manager_create_installer_media_for_path_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->media = _data_->_tmp16_;
#line 100 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					if (_data_->_inner_error_ != NULL) {
#line 1715 "media-manager.c"
						goto __catch59_g_error;
					}
#line 102 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp17_ = NULL;
#line 102 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp17_ = _data_->media;
#line 102 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp18_ = NULL;
#line 102 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp18_ = _g_object_ref0 (_data_->_tmp17_);
#line 102 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->list = g_list_append (_data_->list, _data_->_tmp18_);
#line 99 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_g_object_unref0 (_data_->media);
#line 1730 "media-manager.c"
				}
				goto __finally59;
				__catch59_g_error:
				{
#line 99 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_error_ = _data_->_inner_error_;
#line 99 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_inner_error_ = NULL;
#line 104 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp19_ = NULL;
#line 104 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp19_ = _data_->path;
#line 104 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp20_ = NULL;
#line 104 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp20_ = _data_->_error_;
#line 104 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp21_ = NULL;
#line 104 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_data_->_tmp21_ = _data_->_tmp20_->message;
#line 104 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					g_warning ("media-manager.vala:104: Failed to get information on device '%s': %s. " \
"Ignoring..", _data_->_tmp19_, _data_->_tmp21_);
#line 99 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_g_error_free0 (_data_->_error_);
#line 1755 "media-manager.c"
				}
				__finally59:
#line 99 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				if (_data_->_inner_error_ != NULL) {
#line 99 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_g_free0 (_data_->path);
#line 99 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_g_object_unref0 (_data_->device);
#line 99 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					__g_list_free__g_object_unref0_0 (_data_->device_collection);
#line 99 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					_g_object_unref0 (_data_->enumerator);
#line 99 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					__g_list_free__g_object_unref0_0 (_data_->list);
#line 99 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 99 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					g_clear_error (&_data_->_inner_error_);
#line 99 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
					return FALSE;
#line 1776 "media-manager.c"
				}
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_g_free0 (_data_->path);
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_g_object_unref0 (_data_->device);
#line 1782 "media-manager.c"
			}
		}
#line 93 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		__g_list_free__g_object_unref0_0 (_data_->device_collection);
#line 1787 "media-manager.c"
	}
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp22_ = NULL;
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp22_ = _data_->self->priv->connection;
#line 108 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (_data_->_tmp22_ == NULL) {
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->result = _data_->list;
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->enumerator);
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		if (_data_->_state_ == 0) {
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1803 "media-manager.c"
		} else {
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1807 "media-manager.c"
		}
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_object_unref (_data_->_async_result);
#line 109 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		return FALSE;
#line 1813 "media-manager.c"
	}
	{
#line 113 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp23_ = NULL;
#line 113 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp23_ = _data_->self->priv->connection;
#line 113 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_state_ = 2;
#line 113 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		tracker_sparql_connection_query_async (_data_->_tmp23_, BOXES_MEDIA_MANAGER_SPARQL_QUERY, NULL, boxes_media_manager_list_installer_medias_ready, _data_);
#line 113 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		return FALSE;
#line 1826 "media-manager.c"
		_state_2:
#line 113 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp24_ = NULL;
#line 113 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp24_ = tracker_sparql_connection_query_finish (_data_->_tmp23_, _data_->_res_, &_data_->_inner_error_);
#line 113 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->cursor = _data_->_tmp24_;
#line 113 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		if (_data_->_inner_error_ != NULL) {
#line 1836 "media-manager.c"
			goto __catch60_g_error;
		}
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		while (TRUE) {
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp26_ = NULL;
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp26_ = _data_->cursor;
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_state_ = 3;
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			tracker_sparql_cursor_next_async (_data_->_tmp26_, NULL, boxes_media_manager_list_installer_medias_ready, _data_);
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			return FALSE;
#line 1851 "media-manager.c"
			_state_3:
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp27_ = FALSE;
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp27_ = tracker_sparql_cursor_next_finish (_data_->_tmp26_, _data_->_res_, &_data_->_inner_error_);
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp25_ = _data_->_tmp27_;
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			if (_data_->_inner_error_ != NULL) {
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_g_object_unref0 (_data_->cursor);
#line 1863 "media-manager.c"
				goto __catch60_g_error;
			}
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			if (!_data_->_tmp25_) {
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				break;
#line 1870 "media-manager.c"
			}
#line 115 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp28_ = NULL;
#line 115 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp28_ = _data_->cursor;
#line 115 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp29_ = NULL;
#line 115 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp29_ = tracker_sparql_cursor_get_string (_data_->_tmp28_, 0, NULL);
#line 115 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp30_ = NULL;
#line 115 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp30_ = g_file_new_for_uri (_data_->_tmp29_);
#line 115 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->file = _data_->_tmp30_;
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp31_ = NULL;
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp31_ = _data_->file;
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp32_ = NULL;
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp32_ = g_file_get_path (_data_->_tmp31_);
#line 116 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_vala1_path = _data_->_tmp32_;
#line 117 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp33_ = NULL;
#line 117 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp33_ = _data_->_vala1_path;
#line 117 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			if (_data_->_tmp33_ == NULL) {
#line 118 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_g_free0 (_data_->_vala1_path);
#line 118 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_g_object_unref0 (_data_->file);
#line 118 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				continue;
#line 1908 "media-manager.c"
			}
#line 119 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp34_ = NULL;
#line 119 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp34_ = _data_->cursor;
#line 119 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp35_ = NULL;
#line 119 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp35_ = tracker_sparql_cursor_get_string (_data_->_tmp34_, 1, NULL);
#line 119 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp36_ = NULL;
#line 119 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp36_ = g_strdup (_data_->_tmp35_);
#line 119 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->title = _data_->_tmp36_;
#line 120 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp37_ = NULL;
#line 120 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp37_ = _data_->cursor;
#line 120 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp38_ = NULL;
#line 120 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp38_ = tracker_sparql_cursor_get_string (_data_->_tmp37_, 2, NULL);
#line 120 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp39_ = NULL;
#line 120 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp39_ = g_strdup (_data_->_tmp38_);
#line 120 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->os_id = _data_->_tmp39_;
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp40_ = NULL;
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp40_ = _data_->cursor;
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp41_ = NULL;
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp41_ = tracker_sparql_cursor_get_string (_data_->_tmp40_, 3, NULL);
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp42_ = NULL;
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->_tmp42_ = g_strdup (_data_->_tmp41_);
#line 121 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_data_->media_id = _data_->_tmp42_;
#line 1952 "media-manager.c"
			{
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp43_ = NULL;
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp43_ = _data_->_vala1_path;
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp44_ = NULL;
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp44_ = _data_->title;
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp45_ = NULL;
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp45_ = _data_->os_id;
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp46_ = NULL;
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp46_ = _data_->media_id;
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_state_ = 4;
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				boxes_media_manager_create_installer_media_from_iso_info (_data_->self, _data_->_tmp43_, _data_->_tmp44_, _data_->_tmp45_, _data_->_tmp46_, boxes_media_manager_list_installer_medias_ready, _data_);
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				return FALSE;
#line 1976 "media-manager.c"
				_state_4:
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp47_ = NULL;
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp47_ = boxes_media_manager_create_installer_media_from_iso_info_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_vala1_media = _data_->_tmp47_;
#line 124 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				if (_data_->_inner_error_ != NULL) {
#line 1986 "media-manager.c"
					goto __catch61_g_error;
				}
#line 126 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp48_ = NULL;
#line 126 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp48_ = _data_->_vala1_media;
#line 126 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp49_ = NULL;
#line 126 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp49_ = _g_object_ref0 (_data_->_tmp48_);
#line 126 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->list = g_list_insert_sorted (_data_->list, _data_->_tmp49_, _boxes_media_manager_compare_media_gcompare_func);
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_g_object_unref0 (_data_->_vala1_media);
#line 2001 "media-manager.c"
			}
			goto __finally61;
			__catch61_g_error:
			{
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_vala1__error_ = _data_->_inner_error_;
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_inner_error_ = NULL;
#line 128 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp50_ = NULL;
#line 128 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp50_ = _data_->_vala1_path;
#line 128 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp51_ = NULL;
#line 128 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp51_ = _data_->_vala1__error_;
#line 128 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp52_ = NULL;
#line 128 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_data_->_tmp52_ = _data_->_tmp51_->message;
#line 128 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				g_warning ("media-manager.vala:128: Failed to use ISO '%s': %s", _data_->_tmp50_, _data_->_tmp52_);
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_g_error_free0 (_data_->_vala1__error_);
#line 2026 "media-manager.c"
			}
			__finally61:
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			if (_data_->_inner_error_ != NULL) {
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_g_free0 (_data_->media_id);
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_g_free0 (_data_->os_id);
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_g_free0 (_data_->title);
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_g_free0 (_data_->_vala1_path);
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_g_object_unref0 (_data_->file);
#line 123 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				_g_object_unref0 (_data_->cursor);
#line 2043 "media-manager.c"
				goto __catch60_g_error;
			}
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_g_free0 (_data_->media_id);
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_g_free0 (_data_->os_id);
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_g_free0 (_data_->title);
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_g_free0 (_data_->_vala1_path);
#line 114 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_g_object_unref0 (_data_->file);
#line 2056 "media-manager.c"
		}
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->cursor);
#line 2060 "media-manager.c"
	}
	goto __finally60;
	__catch60_g_error:
	{
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_vala2__error_ = _data_->_inner_error_;
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_inner_error_ = NULL;
#line 132 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp53_ = NULL;
#line 132 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp53_ = _data_->_vala2__error_;
#line 132 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp54_ = NULL;
#line 132 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp54_ = _data_->_tmp53_->message;
#line 132 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_warning ("media-manager.vala:132: Failed to fetch list of ISOs from Tracker: %s.", _data_->_tmp54_);
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_error_free0 (_data_->_vala2__error_);
#line 2081 "media-manager.c"
	}
	__finally60:
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (_data_->_inner_error_ != NULL) {
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->enumerator);
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		__g_list_free__g_object_unref0_0 (_data_->list);
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_clear_error (&_data_->_inner_error_);
#line 112 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		return FALSE;
#line 2096 "media-manager.c"
	}
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->result = _data_->list;
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->enumerator);
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (_data_->_state_ == 0) {
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2106 "media-manager.c"
	} else {
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2110 "media-manager.c"
	}
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_object_unref (_data_->_async_result);
#line 135 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	return FALSE;
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->enumerator);
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	__g_list_free__g_object_unref0_0 (_data_->list);
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (_data_->_state_ == 0) {
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2124 "media-manager.c"
	} else {
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2128 "media-manager.c"
	}
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_object_unref (_data_->_async_result);
#line 85 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	return FALSE;
#line 2134 "media-manager.c"
}


BoxesInstallerMedia* boxes_media_manager_create_installer_media_from_media (BoxesMediaManager* self, BoxesInstallerMedia* media, GError** error) {
	BoxesInstallerMedia* result = NULL;
	BoxesInstallerMedia* _tmp0_ = NULL;
	OsinfoOs* _tmp1_ = NULL;
	OsinfoInstallScriptList* install_scripts = NULL;
	BoxesInstallerMedia* _tmp4_ = NULL;
	OsinfoOs* _tmp5_ = NULL;
	OsinfoInstallScriptList* _tmp6_ = NULL;
	OsinfoFilter* filter = NULL;
	OsinfoFilter* _tmp7_ = NULL;
	OsinfoFilter* _tmp8_ = NULL;
	OsinfoInstallScriptList* _tmp9_ = NULL;
	OsinfoFilter* _tmp10_ = NULL;
	OsinfoList* _tmp11_ = NULL;
	OsinfoInstallScriptList* _tmp12_ = NULL;
	BoxesInstallerMedia* install_media = NULL;
	OsinfoInstallScriptList* _tmp13_ = NULL;
	gint _tmp14_ = 0;
	GError * _inner_error_ = NULL;
#line 138 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 138 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_return_val_if_fail (media != NULL, NULL);
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp0_ = media;
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp1_ = _tmp0_->os;
#line 139 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (_tmp1_ == NULL) {
#line 2167 "media-manager.c"
		BoxesInstallerMedia* _tmp2_ = NULL;
		BoxesInstallerMedia* _tmp3_ = NULL;
#line 140 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_tmp2_ = media;
#line 140 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_tmp3_ = _g_object_ref0 (_tmp2_);
#line 140 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		result = _tmp3_;
#line 140 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		return result;
#line 2178 "media-manager.c"
	}
#line 142 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp4_ = media;
#line 142 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp5_ = _tmp4_->os;
#line 142 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp6_ = osinfo_os_get_install_script_list (_tmp5_);
#line 142 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	install_scripts = _tmp6_;
#line 143 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp7_ = osinfo_filter_new ();
#line 143 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	filter = _tmp7_;
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp8_ = filter;
#line 144 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	osinfo_filter_add_constraint (_tmp8_, OSINFO_INSTALL_SCRIPT_PROP_PROFILE, OSINFO_INSTALL_SCRIPT_PROFILE_DESKTOP);
#line 145 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp9_ = install_scripts;
#line 145 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp10_ = filter;
#line 145 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp11_ = osinfo_list_new_filtered (G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, osinfo_list_get_type ()) ? ((OsinfoList*) _tmp9_) : NULL, _tmp10_);
#line 145 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp12_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp11_, osinfo_install_scriptlist_get_type ()) ? ((OsinfoInstallScriptList*) _tmp11_) : NULL;
#line 145 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (_tmp12_ == NULL) {
#line 145 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_tmp11_);
#line 2208 "media-manager.c"
	}
#line 145 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (install_scripts);
#line 145 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	install_scripts = _tmp12_;
#line 148 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp13_ = install_scripts;
#line 148 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp14_ = osinfo_list_get_length ((OsinfoList*) _tmp13_);
#line 148 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (_tmp14_ > 0) {
#line 2220 "media-manager.c"
		BoxesUnattendedInstaller* _tmp15_ = NULL;
		BoxesInstallerMedia* _tmp16_ = NULL;
		OsinfoInstallScriptList* _tmp17_ = NULL;
		BoxesUnattendedInstaller* _tmp18_ = NULL;
#line 149 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_tmp16_ = media;
#line 149 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_tmp17_ = install_scripts;
#line 149 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_tmp18_ = boxes_unattended_installer_new_from_media (_tmp16_, _tmp17_, &_inner_error_);
#line 149 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_tmp15_ = _tmp18_;
#line 149 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		if (_inner_error_ != NULL) {
#line 149 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_propagate_error (error, _inner_error_);
#line 149 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_g_object_unref0 (install_media);
#line 149 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_g_object_unref0 (filter);
#line 149 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			_g_object_unref0 (install_scripts);
#line 149 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			return NULL;
#line 2245 "media-manager.c"
		}
#line 149 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (install_media);
#line 149 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		install_media = (BoxesInstallerMedia*) _tmp15_;
#line 2251 "media-manager.c"
	} else {
		BoxesInstallerMedia* _tmp19_ = NULL;
		BoxesInstallerMedia* _tmp20_ = NULL;
#line 151 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_tmp19_ = media;
#line 151 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_tmp20_ = _g_object_ref0 (_tmp19_);
#line 151 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (install_media);
#line 151 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		install_media = _tmp20_;
#line 2263 "media-manager.c"
	}
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	result = install_media;
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (filter);
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (install_scripts);
#line 153 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	return result;
#line 2273 "media-manager.c"
}


static BoxesMediaManager* boxes_media_manager_construct (GType object_type) {
	BoxesMediaManager * self = NULL;
	gchar* _tmp0_ = NULL;
	gchar** _tmp1_ = NULL;
	gchar** _tmp2_ = NULL;
	gint _tmp2__length1 = 0;
	GUdevClient* _tmp3_ = NULL;
	GUdevClient* _tmp4_ = NULL;
	BoxesOSDatabase* _tmp5_ = NULL;
	BoxesOSDatabase* _tmp6_ = NULL;
	BoxesOSDatabase* _tmp7_ = NULL;
	GError * _inner_error_ = NULL;
#line 156 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	self = (BoxesMediaManager*) g_object_new (object_type, NULL);
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp0_ = g_strdup ("block");
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp1_ = g_new0 (gchar*, 1 + 1);
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp1_[0] = _tmp0_;
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp2_ = _tmp1_;
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp2__length1 = 1;
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp3_ = g_udev_client_new (_tmp2_);
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp4_ = _tmp3_;
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	boxes_media_manager_set_client (self, _tmp4_);
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_tmp4_);
#line 157 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp2_ = (_vala_array_free (_tmp2_, _tmp2__length1, (GDestroyNotify) g_free), NULL);
#line 158 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp5_ = boxes_os_database_new ();
#line 158 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp6_ = _tmp5_;
#line 158 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	boxes_media_manager_set_os_db (self, _tmp6_);
#line 158 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_tmp6_);
#line 159 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp7_ = self->priv->_os_db;
#line 159 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	boxes_os_database_load (_tmp7_, NULL, NULL);
#line 2323 "media-manager.c"
	{
		TrackerSparqlConnection* _tmp8_ = NULL;
		TrackerSparqlConnection* _tmp9_ = NULL;
#line 161 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_tmp9_ = tracker_sparql_connection_get (NULL, &_inner_error_);
#line 161 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_tmp8_ = _tmp9_;
#line 161 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		if (_inner_error_ != NULL) {
#line 2333 "media-manager.c"
			goto __catch62_g_error;
		}
#line 161 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (self->priv->connection);
#line 161 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		self->priv->connection = _tmp8_;
#line 2340 "media-manager.c"
	}
	goto __finally62;
	__catch62_g_error:
	{
		GError* _error_ = NULL;
		GError* _tmp10_ = NULL;
		const gchar* _tmp11_ = NULL;
#line 160 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_error_ = _inner_error_;
#line 160 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_inner_error_ = NULL;
#line 163 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_tmp10_ = _error_;
#line 163 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_tmp11_ = _tmp10_->message;
#line 163 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_critical ("media-manager.vala:163: Error connecting to Tracker: %s", _tmp11_);
#line 160 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_error_free0 (_error_);
#line 2360 "media-manager.c"
	}
	__finally62:
#line 160 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (_inner_error_ != NULL) {
#line 160 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 160 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_clear_error (&_inner_error_);
#line 160 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		return NULL;
#line 2371 "media-manager.c"
	}
#line 156 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	return self;
#line 2375 "media-manager.c"
}


static BoxesMediaManager* boxes_media_manager_new (void) {
#line 156 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	return boxes_media_manager_construct (BOXES_TYPE_MEDIA_MANAGER);
#line 2382 "media-manager.c"
}


static gint boxes_media_manager_compare_media (BoxesInstallerMedia* media_a, BoxesInstallerMedia* media_b) {
	gint result = 0;
	GCompareFunc _tmp0_ = NULL;
	BoxesInstallerMedia* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	BoxesInstallerMedia* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	gint _tmp5_ = 0;
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_return_val_if_fail (media_a != NULL, 0);
#line 167 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_return_val_if_fail (media_b != NULL, 0);
#line 168 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp0_ = g_strcmp0;
#line 168 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp1_ = media_a;
#line 168 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp2_ = _tmp1_->label;
#line 168 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp3_ = media_b;
#line 168 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp4_ = _tmp3_->label;
#line 168 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp5_ = _tmp0_ (_tmp2_, _tmp4_);
#line 168 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	result = _tmp5_;
#line 168 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	return result;
#line 2414 "media-manager.c"
}


static void boxes_media_manager_create_installer_media_from_iso_info_data_free (gpointer _data) {
	BoxesMediaManagerCreateInstallerMediaFromIsoInfoData* _data_;
	_data_ = _data;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->path);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->label);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->os_id);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->media_id);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->result);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->self);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_slice_free (BoxesMediaManagerCreateInstallerMediaFromIsoInfoData, _data_);
#line 2435 "media-manager.c"
}


static void boxes_media_manager_create_installer_media_from_iso_info (BoxesMediaManager* self, const gchar* path, const gchar* label, const gchar* os_id, const gchar* media_id, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesMediaManagerCreateInstallerMediaFromIsoInfoData* _data_;
	BoxesMediaManager* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	const gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_ = g_slice_new0 (BoxesMediaManagerCreateInstallerMediaFromIsoInfoData);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_media_manager_create_installer_media_from_iso_info);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_media_manager_create_installer_media_from_iso_info_data_free);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->self = _tmp0_;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp1_ = path;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->path);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->path = _tmp2_;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp3_ = label;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp4_ = g_strdup (_tmp3_);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->label);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->label = _tmp4_;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp5_ = os_id;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp6_ = g_strdup (_tmp5_);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->os_id);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->os_id = _tmp6_;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp7_ = media_id;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp8_ = g_strdup (_tmp7_);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->media_id);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->media_id = _tmp8_;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	boxes_media_manager_create_installer_media_from_iso_info_co (_data_);
#line 2494 "media-manager.c"
}


static BoxesInstallerMedia* boxes_media_manager_create_installer_media_from_iso_info_finish (BoxesMediaManager* self, GAsyncResult* _res_, GError** error) {
	BoxesInstallerMedia* result;
	BoxesMediaManagerCreateInstallerMediaFromIsoInfoData* _data_;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		return NULL;
#line 2505 "media-manager.c"
	}
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	result = _data_->result;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->result = NULL;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	return result;
#line 2515 "media-manager.c"
}


static void boxes_media_manager_create_installer_media_from_iso_info_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesMediaManagerCreateInstallerMediaFromIsoInfoData* _data_;
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_ = _user_data_;
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_source_object_ = source_object;
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_res_ = _res_;
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	boxes_media_manager_create_installer_media_from_iso_info_co (_data_);
#line 2529 "media-manager.c"
}


static gboolean boxes_media_manager_create_installer_media_from_iso_info_co (BoxesMediaManagerCreateInstallerMediaFromIsoInfoData* _data_) {
#line 171 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	switch (_data_->_state_) {
#line 171 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		case 0:
#line 2538 "media-manager.c"
		goto _state_0;
#line 171 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		case 1:
#line 2542 "media-manager.c"
		goto _state_1;
#line 171 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		case 2:
#line 2546 "media-manager.c"
		goto _state_2;
		default:
#line 171 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_assert_not_reached ();
#line 2551 "media-manager.c"
	}
	_state_0:
#line 175 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp0_ = NULL;
#line 175 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp0_ = _data_->path;
#line 175 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp1_ = FALSE;
#line 175 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp1_ = g_file_test (_data_->_tmp0_, G_FILE_TEST_EXISTS);
#line 175 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (!_data_->_tmp1_) {
#line 176 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp2_ = NULL;
#line 176 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp2_ = _ ("No such file %s");
#line 176 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp3_ = NULL;
#line 176 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp3_ = _data_->path;
#line 176 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp4_ = NULL;
#line 176 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp4_ = g_strdup_printf (_data_->_tmp2_, _data_->_tmp3_);
#line 176 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp5_ = NULL;
#line 176 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp5_ = _data_->_tmp4_;
#line 176 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp6_ = NULL;
#line 176 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp6_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, _data_->_tmp5_);
#line 176 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp7_ = NULL;
#line 176 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp7_ = _data_->_tmp6_;
#line 176 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_free0 (_data_->_tmp5_);
#line 176 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_inner_error_ = _data_->_tmp7_;
#line 176 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 176 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_error_free (_data_->_inner_error_);
#line 176 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		if (_data_->_state_ == 0) {
#line 176 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2600 "media-manager.c"
		} else {
#line 176 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2604 "media-manager.c"
		}
#line 176 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_object_unref (_data_->_async_result);
#line 176 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		return FALSE;
#line 2610 "media-manager.c"
	}
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp10_ = NULL;
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp10_ = _data_->label;
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (_data_->_tmp10_ == NULL) {
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp9_ = TRUE;
#line 2620 "media-manager.c"
	} else {
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp11_ = NULL;
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp11_ = _data_->os_id;
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp9_ = _data_->_tmp11_ == NULL;
#line 2628 "media-manager.c"
	}
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp12_ = FALSE;
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp12_ = _data_->_tmp9_;
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (_data_->_tmp12_) {
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp8_ = TRUE;
#line 2638 "media-manager.c"
	} else {
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp13_ = NULL;
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp13_ = _data_->media_id;
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp8_ = _data_->_tmp13_ == NULL;
#line 2646 "media-manager.c"
	}
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp14_ = FALSE;
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp14_ = _data_->_tmp8_;
#line 178 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (_data_->_tmp14_) {
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp16_ = NULL;
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp16_ = _data_->path;
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_state_ = 1;
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		boxes_media_manager_create_installer_media_for_path (_data_->self, _data_->_tmp16_, NULL, boxes_media_manager_create_installer_media_from_iso_info_ready, _data_);
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		return FALSE;
#line 2664 "media-manager.c"
		_state_1:
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp17_ = NULL;
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp17_ = boxes_media_manager_create_installer_media_for_path_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->_tmp15_ = _data_->_tmp17_;
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		if (_data_->_inner_error_ != NULL) {
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_error_free (_data_->_inner_error_);
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			if (_data_->_state_ == 0) {
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2682 "media-manager.c"
			} else {
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 2686 "media-manager.c"
			}
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_object_unref (_data_->_async_result);
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			return FALSE;
#line 2692 "media-manager.c"
		}
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_data_->result = _data_->_tmp15_;
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		if (_data_->_state_ == 0) {
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2700 "media-manager.c"
		} else {
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2704 "media-manager.c"
		}
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_object_unref (_data_->_async_result);
#line 179 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		return FALSE;
#line 2710 "media-manager.c"
	}
#line 181 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp18_ = NULL;
#line 181 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp18_ = _data_->self->priv->_os_db;
#line 181 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp19_ = NULL;
#line 181 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp19_ = _data_->os_id;
#line 181 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_state_ = 2;
#line 181 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	boxes_os_database_get_os_by_id (_data_->_tmp18_, _data_->_tmp19_, boxes_media_manager_create_installer_media_from_iso_info_ready, _data_);
#line 181 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	return FALSE;
#line 2726 "media-manager.c"
	_state_2:
#line 181 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp20_ = NULL;
#line 181 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp20_ = boxes_os_database_get_os_by_id_finish (_data_->_tmp18_, _data_->_res_, &_data_->_inner_error_);
#line 181 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->os = _data_->_tmp20_;
#line 181 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (_data_->_inner_error_ != NULL) {
#line 181 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 181 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_error_free (_data_->_inner_error_);
#line 181 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		if (_data_->_state_ == 0) {
#line 181 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2744 "media-manager.c"
		} else {
#line 181 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2748 "media-manager.c"
		}
#line 181 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_object_unref (_data_->_async_result);
#line 181 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		return FALSE;
#line 2754 "media-manager.c"
	}
#line 182 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp21_ = NULL;
#line 182 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp21_ = _data_->self->priv->_os_db;
#line 182 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp22_ = NULL;
#line 182 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp22_ = _data_->os;
#line 182 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp23_ = NULL;
#line 182 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp23_ = _data_->media_id;
#line 182 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp24_ = NULL;
#line 182 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp24_ = boxes_os_database_get_media_by_id (_data_->_tmp21_, _data_->_tmp22_, _data_->_tmp23_, &_data_->_inner_error_);
#line 182 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->os_media = _data_->_tmp24_;
#line 182 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (_data_->_inner_error_ != NULL) {
#line 182 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 182 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_error_free (_data_->_inner_error_);
#line 182 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->os);
#line 182 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		if (_data_->_state_ == 0) {
#line 182 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2786 "media-manager.c"
		} else {
#line 182 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2790 "media-manager.c"
		}
#line 182 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_object_unref (_data_->_async_result);
#line 182 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		return FALSE;
#line 2796 "media-manager.c"
	}
#line 183 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp25_ = NULL;
#line 183 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp25_ = _data_->self->priv->_os_db;
#line 183 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp26_ = NULL;
#line 183 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp26_ = _data_->os;
#line 183 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp27_ = NULL;
#line 183 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp27_ = _data_->os_media;
#line 183 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp28_ = NULL;
#line 183 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_object_get (_data_->_tmp27_, "architecture", &_data_->_tmp28_, NULL);
#line 183 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp29_ = NULL;
#line 183 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp29_ = _data_->_tmp28_;
#line 183 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp30_ = NULL;
#line 183 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp30_ = _data_->_tmp29_;
#line 183 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp31_ = NULL;
#line 183 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp31_ = boxes_os_database_get_resources_for_os (_data_->_tmp25_, _data_->_tmp26_, _data_->_tmp30_);
#line 183 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp32_ = NULL;
#line 183 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp32_ = _data_->_tmp31_;
#line 183 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_free0 (_data_->_tmp30_);
#line 183 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->resources = _data_->_tmp32_;
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp33_ = NULL;
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp33_ = _data_->path;
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp34_ = NULL;
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp34_ = _data_->label;
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp35_ = NULL;
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp35_ = _data_->os;
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp36_ = NULL;
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp36_ = _data_->os_media;
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp37_ = NULL;
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp37_ = _data_->resources;
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp38_ = NULL;
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp38_ = boxes_installer_media_new_from_iso_info (_data_->_tmp33_, _data_->_tmp34_, _data_->_tmp35_, _data_->_tmp36_, _data_->_tmp37_);
#line 184 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->media = _data_->_tmp38_;
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp40_ = NULL;
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp40_ = _data_->media;
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp41_ = NULL;
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp41_ = boxes_media_manager_create_installer_media_from_media (_data_->self, _data_->_tmp40_, &_data_->_inner_error_);
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->_tmp39_ = _data_->_tmp41_;
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (_data_->_inner_error_ != NULL) {
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_error_free (_data_->_inner_error_);
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->media);
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->resources);
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->os_media);
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		_g_object_unref0 (_data_->os);
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		if (_data_->_state_ == 0) {
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2888 "media-manager.c"
		} else {
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2892 "media-manager.c"
		}
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_object_unref (_data_->_async_result);
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		return FALSE;
#line 2898 "media-manager.c"
	}
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_data_->result = _data_->_tmp39_;
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->media);
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->resources);
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->os_media);
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->os);
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (_data_->_state_ == 0) {
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2914 "media-manager.c"
	} else {
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2918 "media-manager.c"
	}
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_object_unref (_data_->_async_result);
#line 186 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	return FALSE;
#line 171 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->media);
#line 171 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->resources);
#line 171 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->os_media);
#line 171 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (_data_->os);
#line 171 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	if (_data_->_state_ == 0) {
#line 171 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2936 "media-manager.c"
	} else {
#line 171 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2940 "media-manager.c"
	}
#line 171 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_object_unref (_data_->_async_result);
#line 171 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	return FALSE;
#line 2946 "media-manager.c"
}


BoxesOSDatabase* boxes_media_manager_get_os_db (BoxesMediaManager* self) {
	BoxesOSDatabase* result;
	BoxesOSDatabase* _tmp0_ = NULL;
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp0_ = self->priv->_os_db;
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	result = _tmp0_;
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	return result;
#line 2961 "media-manager.c"
}


static void boxes_media_manager_set_os_db (BoxesMediaManager* self, BoxesOSDatabase* value) {
	BoxesOSDatabase* _tmp0_ = NULL;
	BoxesOSDatabase* _tmp1_ = NULL;
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_return_if_fail (self != NULL);
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp0_ = value;
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (self->priv->_os_db);
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	self->priv->_os_db = _tmp1_;
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_object_notify ((GObject *) self, "os-db");
#line 2980 "media-manager.c"
}


GUdevClient* boxes_media_manager_get_client (BoxesMediaManager* self) {
	GUdevClient* result;
	GUdevClient* _tmp0_ = NULL;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp0_ = self->priv->_client;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	result = _tmp0_;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	return result;
#line 2995 "media-manager.c"
}


static void boxes_media_manager_set_client (BoxesMediaManager* self, GUdevClient* value) {
	GUdevClient* _tmp0_ = NULL;
	GUdevClient* _tmp1_ = NULL;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_return_if_fail (self != NULL);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp0_ = value;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (self->priv->_client);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	self->priv->_client = _tmp1_;
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_object_notify ((GObject *) self, "client");
#line 3014 "media-manager.c"
}


static void boxes_media_manager_class_init (BoxesMediaManagerClass * klass) {
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	boxes_media_manager_parent_class = g_type_class_peek_parent (klass);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_type_class_add_private (klass, sizeof (BoxesMediaManagerPrivate));
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_media_manager_get_property;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_media_manager_set_property;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_media_manager_finalize;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_MEDIA_MANAGER_OS_DB, g_param_spec_object ("os-db", "os-db", "os-db", BOXES_TYPE_OS_DATABASE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_MEDIA_MANAGER_CLIENT, g_param_spec_object ("client", "client", "client", g_udev_client_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 3033 "media-manager.c"
}


static void boxes_media_manager_instance_init (BoxesMediaManager * self) {
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	self->priv = BOXES_MEDIA_MANAGER_GET_PRIVATE (self);
#line 3040 "media-manager.c"
}


static void boxes_media_manager_finalize (GObject* obj) {
	BoxesMediaManager * self;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManager);
#line 12 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (self->priv->_os_db);
#line 13 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (self->priv->_client);
#line 17 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	_g_object_unref0 (self->priv->connection);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	G_OBJECT_CLASS (boxes_media_manager_parent_class)->finalize (obj);
#line 3056 "media-manager.c"
}


GType boxes_media_manager_get_type (void) {
	static volatile gsize boxes_media_manager_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_media_manager_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesMediaManagerClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_media_manager_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesMediaManager), 0, (GInstanceInitFunc) boxes_media_manager_instance_init, NULL };
		GType boxes_media_manager_type_id;
		boxes_media_manager_type_id = g_type_register_static (G_TYPE_OBJECT, "BoxesMediaManager", &g_define_type_info, 0);
		g_once_init_leave (&boxes_media_manager_type_id__volatile, boxes_media_manager_type_id);
	}
	return boxes_media_manager_type_id__volatile;
}


static void _vala_boxes_media_manager_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesMediaManager * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManager);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	switch (property_id) {
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		case BOXES_MEDIA_MANAGER_OS_DB:
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_value_set_object (value, boxes_media_manager_get_os_db (self));
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		break;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		case BOXES_MEDIA_MANAGER_CLIENT:
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		g_value_set_object (value, boxes_media_manager_get_client (self));
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		break;
#line 3089 "media-manager.c"
		default:
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		break;
#line 3095 "media-manager.c"
	}
}


static void _vala_boxes_media_manager_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesMediaManager * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManager);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
	switch (property_id) {
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		case BOXES_MEDIA_MANAGER_OS_DB:
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		boxes_media_manager_set_os_db (self, g_value_get_object (value));
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		break;
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		case BOXES_MEDIA_MANAGER_CLIENT:
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		boxes_media_manager_set_client (self, g_value_get_object (value));
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		break;
#line 3117 "media-manager.c"
		default:
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 7 "/extra-data/checkout/gnome/gnome-boxes/src/media-manager.vala"
		break;
#line 3123 "media-manager.c"
	}
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
#line 471 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if ((array != NULL) && (destroy_func != NULL)) {
#line 3131 "media-manager.c"
		int i;
#line 471 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		for (i = 0; i < array_length; i = i + 1) {
#line 471 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			if (((gpointer*) array)[i] != NULL) {
#line 471 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				destroy_func (((gpointer*) array)[i]);
#line 3139 "media-manager.c"
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
#line 471 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_vala_array_destroy (array, array_length, destroy_func);
#line 471 "/extra-data/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_free (array);
#line 3151 "media-manager.c"
}



